const express = require('express');
const http = require('http');
const path = require('path');
const passport = require('passport');
const morgan = require('morgan');
const cookieParser = require('cookie-parser');
const bodyParser = require('body-parser');
const session = require('express-session');
const errorhandler = require('errorhandler');
const flash = require('express-flash');

var env = process.env.NODE_ENV || 'development';
const config = require('./config/config')[env];

var app = express();

app.set('port', config.app.port);
app.set('views', __dirname + '/views');
app.set('view engine', 'pug');
app.use(morgan('combined'));
app.use(cookieParser());
app.use(bodyParser.json());
app.use(bodyParser.urlencoded({extended: false}));
app.use(express.static(path.join(__dirname, 'public')));

app.use(session(
  {
    resave: true,
    saveUninitialized: true,
    secret: 'thisisasecret'
  }
));
app.use(flash());
app.use((req, res, next) => {
  res.locals.errors = req.flash("error");
  res.locals.successes = req.flash("success");
  next();
});

app.use(passport.initialize());
app.use(passport.session());

// caching disabled for every route
// NOTE: Works in Firefox and Opera. Does not work in Edge
app.use(function(req, res, next) {
  res.set('Cache-Control', 'no-cache, private, no-store, must-revalidate, max-stale=0, post-check=0, pre-check=0');
  next();
});

require('./routes/routes')(app, config, passport);
//require('./routes/dbconn')(app, config);
require('./routes/api')(app, config, passport);

app.listen(app.get('port'), function () {
  console.log('Express server listening on port ' + app.get('port'));
});
